@@ -13,12 +13,11 @@
 #   under the License.
 #
 
-import six
 import time
+from unittest import mock
 import uuid
 
 from cliff import columns as cliff_columns
-import mock
 
 from osc_lib.cli import format_columns
 from osc_lib import exceptions
@@ -206,11 +205,7 @@ class TestUtils(test_utils.TestCase):
         item4 = {'a': 1}
         items = [item1, item2, item3, item4]
         sort_str = 'a'
-        expect_items = [item3, item4, item1, item2]
-        if six.PY2:
-            self.assertEqual(expect_items, utils.sort_items(items, sort_str))
-        else:
-            self.assertRaises(TypeError, utils.sort_items, items, sort_str)
+        self.assertRaises(TypeError, utils.sort_items, items, sort_str)
 
     def test_sort_items_with_different_type_int(self):
         item1 = {'a': 2}
@@ -689,6 +684,50 @@ class TestFindResource(test_utils.TestCase):
                          utils.format_dict({'e': 'f', 'c': 'd', 'a': 'b'}))
         self.assertIsNone(utils.format_dict(None))
 
+    def test_format_dict_recursive(self):
+        expected = "a='b', c.1='d', c.2=''"
+        self.assertEqual(
+            expected,
+            utils.format_dict({'a': 'b', 'c': {'1': 'd', '2': ''}})
+        )
+        self.assertEqual(
+            expected,
+            utils.format_dict({'c': {'1': 'd', '2': ''}, 'a': 'b'})
+        )
+        self.assertIsNone(utils.format_dict(None))
+
+        expected = "a1='A', a2.b1.c1='B', a2.b1.c2=, a2.b2='D'"
+        self.assertEqual(
+            expected,
+            utils.format_dict(
+                {
+                    'a1': 'A',
+                    'a2': {
+                        'b1': {
+                            'c1': 'B',
+                            'c2': None,
+                        },
+                        'b2': 'D',
+                    },
+                }
+            )
+        )
+        self.assertEqual(
+            expected,
+            utils.format_dict(
+                {
+                    'a2': {
+                        'b1': {
+                            'c2': None,
+                            'c1': 'B',
+                        },
+                        'b2': 'D',
+                    },
+                    'a1': 'A',
+                }
+            )
+        )
+
     def test_format_dict_of_list(self):
         expected = "a=a1, a2; b=b1, b2; c=c1, c2; e="
         self.assertEqual(expected,
